Download content from the connector
Source:R/connector_imports.R, R/volume_methods.R
download_cnt.RdAddition list content methods for databricks connectors implemented for
connector::download_cnt():
ConnectorDatabricksVolume: Reuses the
connector::download_cnt()method for ConnectorDatabricksVolume, but always sets thecatalogandschemaas defined in when initializing the connector.
Arguments
- connector_object
Connector The connector object to use.
- name
character Name of the content to read, write, or remove. Typically the table name.
- file
character Path to the file to download to or upload from
- ...
ConnectorDatabricksVolume: Additional parameters to pass to the
brickster::db_volume_read()method
Value
ConnectorDatabricksVolume object