Skip to contents

Addition list content methods for databricks connectors implemented for connector::download_directory_cnt():

Usage

download_directory_cnt(connector_object, name, dir = name, ...)

Arguments

connector_object

Connector The connector object to use.

name

character The name of the directory to download

dir

character Path to the directory to download to

...

Additional arguments passed to the method for the individual connector.

Value

invisible connector_object.