Remove content from the connector
Source:R/connector_imports.R, R/table_methods.R, R/volume_methods.R
remove_cnt.RdAddition remove methods for databricks connectors implemented for
connector::remove_cnt():
ConnectorDatabricksTable: Reuses the
connector::remove_cnt()method for connector::connector_dbi, but always sets thecatalogandschemaas defined in when initializing the connector.
ConnectorDatabricksVolume: Reuses the
connector::remove_cnt()method for ConnectorDatabricksVolume, but always sets thecatalogandschemaas defined in when initializing the connector.
Usage
remove_cnt(connector_object, name, ...)
# S3 method for class 'ConnectorDatabricksTable'
remove_cnt(connector_object, name, ...)
# S3 method for class 'ConnectorDatabricksVolume'
remove_cnt(connector_object, name, ...)Value
ConnectorDatabricksVolume object