Addition list content methods for databricks connectors implemented for
connector::upload_cnt():
ConnectorDatabricksVolume: Reuses the
connector::upload_cnt()method for ConnectorDatabricksVolume, but always sets thecatalogandschemaas defined in when initializing the connector.
Usage
upload_cnt(
connector_object,
file,
name = basename(file),
overwrite = zephyr::get_option("overwrite", "connector"),
...
)
# S3 method for class 'ConnectorDatabricksVolume'
upload_cnt(
connector_object,
file,
name = basename(file),
overwrite = zephyr::get_option("overwrite", "connector.databricks"),
...
)Arguments
- connector_object
Connector The connector object to use.
- file
character Path to the file to download to or upload from
- name
character Name of the content to read, write, or remove. Typically the table name.
- overwrite
Overwrites existing content if it exists in the connector.
- ...
ConnectorDatabricksVolume: Additional parameters to pass to the
brickster::db_volume_write()method
Value
ConnectorDatabricksVolume object